@@ -216,7 +216,7 @@ def main(argv=None, stdout=None):
     parser.add_option(
         "--version-map", dest='version_map', default=[], action='append',
         help=('Add a : separated list of versions to clone.  To \'clone\' '
-              'a freeze geberated by python3.4 to python3.5 specify 3.4:3.5.  '
+              'a freeze generated by python3.4 to python3.5 specify 3.4:3.5.  '
               'This is intended as as a way to transition between python '
               'versions when it\'s not possible to have all versions '
               'installed'))
